'use strict';

/*global module:false*/
/*global require*/

var bannerCopy = '<%= pkg.name %> - v<%= pkg.version %> - <%= grunt.template.today("yyyy-mm-dd") %> DO NOT MODIFY THIS FILE DIRECTLY OR YOU WILL NOT BE ABLE TO UPDATE YOUR VERSION OF SPARK.';

module.exports = function(grunt) {

  // Loads only necessary dependencies during runtime
  // "Will automatically search for the plugin from the task name. Search in the following order:
  // 1) node_modules/grunt-contrib-task-name
  // 2) node_modules/grunt-task-name
  // 3) node_modules/task-name
  require('jit-grunt')(grunt, {
    cmq: 'grunt-combine-media-queries',
    htmlbuild: 'grunt-html-build'
  });

  // Project configuration.
  grunt.initConfig({
    // Metadata.
    pkg: grunt.file.readJSON('package.json'),
    banner: '',
    autoprefixer: {
      options: {
        browsers: ['last 4 versions']
      }
    },
    jshint: {
      all: ['js/**/*.js'],
      options: {
        ignores: [],
        jshintrc: true
      }
    },
    cmq: {
      options: {
        log: true
      },
      dist: {
        files: {
          'dist/css': ['dist/css/*.css']
        }
      },
      tmp: {
        files: {
          '.tmp/css': ['.tmp/css/*.css']
        }
      }
    },
    htmlbuild:{
      dist: {
        src: 'examples/partials/.tmp/**/*.html',
        dest: 'examples/built',
        options: {
          beautify: true,
          prefix: '',
          relative: true,
          sections:{
            layout: {
              header: 'examples/templates/header.html',
              headerWhiteLabel: 'examples/templates/header--whitelabel.html',
              headerStickyFooter: 'examples/templates/header--sticky-footer.html',
              footer: 'examples/templates/footer.html'
            }
          }
        },
      },
    },
    watch: {
      options: {
        livereload: 1337,
      },
      sass: {
        files: [
          './scss/**/*.scss'
        ],
        tasks: ['tmpCSS']
      },
      js:{
        files:['./js/**/*.js'],
        tasks: ['tmpJS']
      },
      examples:{
        files:['./examples/**/*.*','!./examples/built','!./examples/**/.tmp'],
        tasks: ['examples']
      },
    },
    connect: {
      server: {
        options: {
          livereload: 1337,
          base: './',
          useAvailablePort: true,
          host: '0.0.0.0'
        }
      }
    },
    clean: {
      tmpPartials: ['examples/partials/.tmp','examples/built/*.html'],
      tmpImages: ['.tmp/images'],
      tmpCSS: ['.tmp/css/*.css','.tmp/css/*.map'],
      tmpJS: ['.tmp/js'],
      distFull: ['dist', '.tmp'],
      distQuick: ['dist/css/*.css', 'dist/css/*.map','dist/js', '.tmp'],
      distPost: ['.tmp', 'dist/scripts.html'],
      default: ['.tmp']
    },
    uglify: {
      dist: {
        options: {
          sourcemaps: true
        },
        files: [{
          expand: true,
          cwd: '.tmp/js',
          src: ['spark.js'],
          dest: 'dist/js'
        }]
      }
    },
    concat: {
      htmlbuild: {
        files: [{
          expand: true,
          cwd: 'examples/partials',
          src: '**/*.html',
          dest: 'examples/partials/.tmp'
        }],
        options: {
          banner: '\n<!-- build:section layout.header -->'+
                  '<!-- /build -->\n',
          footer: '\n<!-- build:section layout.footer -->'+
                  '<!-- /build -->\n'
        }
      },
      htmlbuildWhiteLabel: {
        files: [{
          expand: true,
          cwd: 'examples/partials',
          src: 'whitelabel/**/*.html',
          dest: 'examples/partials/.tmp'
        }],
        options: {
          banner: '\n<!-- build:section layout.headerWhiteLabel -->'+
                  '<!-- /build -->\n',
          footer: '\n<!-- build:section layout.footer -->'+
                  '<!-- /build -->\n'
        }
      },
      htmlbuildStickyFooter: {
        files: [{
          expand: true,
          cwd: 'examples/partials',
          src: 'sticky-footer/**/*.html',
          dest: 'examples/partials/.tmp'
        }],
        options: {
          banner: '\n<!-- build:section layout.headerStickyFooter -->'+
                  '<!-- /build -->\n',
          footer: '\n<!-- build:section layout.footer -->'+
                  '<!-- /build -->\n'
        }
      },
      js: {
        src: [
          '.tmp/js/components/base.js',
          '.tmp/js/helpers/each.js',
          '.tmp/js/helpers/set-caret.js',
          '.tmp/js/helpers/store-form-data.js',
          '.tmp/js/helpers/build-select.js',
          '.tmp/js/helpers/date.js',
          '.tmp/js/helpers/outer-height.js',
          '.tmp/js/helpers/pad-number.js',
          '.tmp/js/helpers/animate-height.js',
          '.tmp/js/helpers/parse-date-format.js',
          '.tmp/js/helpers/transform.js',
          '.tmp/js/helpers/typeahead.js',
          '.tmp/js/helpers/date-typeahead.js',
          '.tmp/js/helpers/debounce.js',
          '.tmp/js/components/expand.js',
          '.tmp/js/components/expand.js',
          '.tmp/js/components/menu.js',
          '.tmp/js/components/modal.js',
          '.tmp/js/components/header.js',
          '.tmp/js/components/number-selector.js',
          '.tmp/js/components/number-picker.js',
          '.tmp/js/components/text-input.js',
          '.tmp/js/components/popover.js',
          '.tmp/js/components/select-input.js',
          '.tmp/js/helpers/date-select.js',
          '.tmp/js/components/calendar-popover.js',
          '.tmp/js/components/date-input.js',
          '.tmp/js/components/range-slider.js',
          '.tmp/js/components/progress-indicator.js',
          '.tmp/js/components/slider.js',
          '.tmp/js/components/table.js',
          '.tmp/js/components/tabs.js',
          '.tmp/js/components/toggle-switch.js',
          '.tmp/js/components/toolbar.js',
          '.tmp/js/components/carousel.js',
          '.tmp/js/components/scroll-to-top.js',
          '.tmp/js/components/step-indicator.js'
        ],
        dest: '.tmp/js/spark.js'
      },
      jsBanner: {
        options: {
          banner: '/*! ' + bannerCopy + ' */\n',
        },
        src: [
          'dist/js/spark.js'
        ],
        dest: 'dist/js/spark.js'
      },
      jsMinBanner: {
        options: {
          banner: '/*! ' + bannerCopy + ' */\n',
        },
        src: [
          'dist/js/spark.min.js'
        ],
        dest: 'dist/js/spark.min.js'
      },
      cssLightBanner: {
        options: {
          banner: '/*! ' + bannerCopy + ' */\n',
        },
        src: [
          'dist/css/spark.light.css'
        ],
        dest: 'dist/css/spark.light.css'
      },
      cssLightMinBanner: {
        options: {
          banner: '/*! ' + bannerCopy + ' */\n',
        },
        src: [
          'dist/css/spark.light.min.css'
        ],
        dest: 'dist/css/spark.light.min.css'
      },
      cssWhitelabelBanner: {
        options: {
          banner: '/*! ' + bannerCopy + ' */\n',
        },
        src: [
          'dist/css/spark.whitelabel.css'
        ],
        dest: 'dist/css/spark.whitelabel.css'
      },
      cssWhitelabelMinBanner: {
        options: {
          banner: '/*! ' + bannerCopy + ' */\n',
        },
        src: [
          'dist/css/spark.whitelabel.min.css'
        ],
        dest: 'dist/css/spark.whitelabel.min.css'
      }
    },
    compress: {
      distribute: {
        options: {
          archive: 'archive/spark-base-repo.zip'
        },
        files: [
          {expand: true,
          cwd: './',
          src: [
            '**/*',
            '!**/.sass-cache/**',
            '!**/node_modules/**',
            '!**/.git/**',
            '!**/www/**',
            '!**/archive/**'
          ],
          dest: 'spark-base-repo/'}, // makes all src relative to cwd
        ]
      }
    },
    sass: {
      options:{
        sourceMap: false
      },
      default: {
        files: {
          './.tmp/css/spark.whitelabel.css': './scss/spark.whitelabel.scss',
          './.tmp/css/spark.light.css': './scss/spark.light.scss'
        }
      },
      dist:{
        files: {
          './.tmp/css/spark.whitelabel.css': './scss/spark.whitelabel.scss',
          './.tmp/css/spark.light.css': './scss/spark.light.scss'
        }
      }
    },
    postcss: {
      default: {
        options: {
          map: {
            inline: false, // save all sourcemaps as separate files...
            annotation: 'dist/css/' // ...to the specified directory
          },
          processors: [
            require('pixrem')(), // add fallbacks for rem units
            require('autoprefixer')({browsers: 'last 4 versions'}) // add vendor prefixes
          ]
        },
        src: '.tmp/css/*.css',
      },
      dist: {
        options: {
          map: {
            inline: false, // save all sourcemaps as separate files...
            annotation: 'dist/css/' // ...to the specified directory
          },
          processors: [
            require('pixrem')(), // add fallbacks for rem units
            require('autoprefixer')({browsers: 'last 4 versions'}), // add vendor prefixes
            require('cssnano')({safe: true}) // Currently, this disables custom identifier reduction, z-index rebasing, unused at-rule removal & conversion between absolute length values.
          ]
        },
        src: 'dist/css/*.min.css'
      }
    },
    copy: {
      sparkIcons: {
        files: [
          {
            expand: true,
            // Hologram was here
            cwd: 'node_modules/sabre-spark-extras/icons/build/fonts/',
            src: ['**'],
            dest: 'scss/fonts/spark/',
            filter: 'isFile'
          }
        ]
      },
      images: {
        files: [
          {
            expand: true,
            // Hologram was here
            cwd: 'images/',
            src: ['**'],
            dest: '.tmp/images/',
            filter: 'isFile'
          }
        ]
      },
      fonts: {
        files: [
          {
            expand: true,
            // Hologram was here
            cwd: 'scss/fonts/',
            src: ['**'],
            dest: 'dist/css/fonts/',
            filter: 'isFile'
          }
        ]
      },
      fontsTmp: {
        files: [
          {
            expand: true,
            // Hologram was here
            cwd: 'scss/fonts/',
            src: ['**'],
            dest: '.tmp/css/fonts/',
            filter: 'isFile'
          }
        ]
      },
      js: {
        files: [
          {
            expand: true,
            cwd: 'js/',
            src: ['**/*.js'],
            // flatten: true,
            dest: '.tmp/js/',
            filter: 'isFile'
          }
        ]
      },
      distJS: {
        files: [
          {
            src: 'js/spark.js',
            dest: 'dist/js/spark.js',
            filter: 'isFile'
          }
        ]
      },
      distImages: {
        files: [
          {
            expand: true,
            cwd: 'images/',
            src: ['**'],
            dest: 'dist/images/',
            filter: 'isFile'
          },
        ]
      },
      distCSS: {
        files: [
          {
            src: '.tmp/css/spark.whitelabel.css',
            dest: 'dist/css/spark.whitelabel.css',
            filter: 'isFile'
          },
          {
            src: '.tmp/css/spark.whitelabel.css.map',
            dest: 'dist/css/spark.whitelabel.css.map',
            filter: 'isFile'
          },
          {
            src: '.tmp/css/spark.light.css',
            dest: 'dist/css/spark.light.css',
            filter: 'isFile'
          },
          {
            src: '.tmp/css/spark.light.css.map',
            dest: 'dist/css/spark.light.css.map',
            filter: 'isFile'
          }
        ]
      },
      renameMinJS:{
        files: [
          {
            src: 'dist/js/spark.js',
            dest: 'dist/js/spark.min.js',
            filter: 'isFile'
          },
          {
            src: '.tmp/js/spark.js',
            dest: 'dist/js/spark.js',
            filter: 'isFile'
          },
        ]
      },
      renameMinCSS:{
        files: [
          {
            src: 'dist/css/spark.whitelabel.css',
            dest: 'dist/css/spark.whitelabel.min.css',
            filter: 'isFile'
          },
          {
            src: '.tmp/css/spark.light.css',
            dest: 'dist/css/spark.light.min.css',
            filter: 'isFile'
          },
        ]
      },
      distPost: {
        files: [
          {
            src: '.tmp/css/spark.whitelabel.css',
            dest: 'dist/css/spark.whitelabel.css',
            filter: 'isFile'
          },
          {
            src: '.tmp/css/spark.whitelabel.min.css',
            dest: 'dist/css/spark.whitelabel.min.css',
            filter: 'isFile'
          },
          {
            src: '.tmp/css/spark.whitelabel.css.map',
            dest: 'dist/css/spark.whitelabel.css.map',
            filter: 'isFile'
          },
          {
            src: '.tmp/css/spark.light.css',
            dest: 'dist/css/spark.light.css',
            filter: 'isFile'
          },
          {
            src: '.tmp/css/spark.light.css.map',
            dest: 'dist/css/spark.light.css.map',
            filter: 'isFile'
          },
          {
            src: ['js/index.js', 'js/components/**/*', 'js/helpers/**/*'],
            dest: 'dist/',
            filter: 'isFile'
          }
        ]
      }
    }
  });

  // Base task for cleaning and copying files to a central location
  grunt.registerTask('tmpJS',['clean:tmpJS', 'copy:js', 'concat:js', 'copy:distJS']);
  grunt.registerTask('tmpCSS', ['clean:tmpCSS', 'sass:default', 'postcss:default', 'copy:distCSS']);
  grunt.registerTask('tmpImages', ['clean:tmpImages', 'copy:distImages']);

  grunt.registerTask('default', ['jshint', 'tmpCSS', 'cmq:tmp', 'copy:fonts', 'copy:images', 'tmpJS', 'tmpImages']);

  // Leaves files unminified, used to develop the library in conjunction with documentation website
  grunt.registerTask('dev', ['clean:distQuick', 'default', 'copy:distPost','tmpJS','copy:fontsTmp', 'copy:sparkIcons', 'copy:images','examples','connect','watch']);

  // Add banners to built files
  grunt.registerTask('banners', ['concat:jsBanner', 'concat:jsMinBanner', 'concat:cssLightBanner', 'concat:cssLightMinBanner', 'concat:cssWhitelabelBanner', 'concat:cssWhitelabelMinBanner']);

  // Minifies and creates production ready code
  grunt.registerTask('dist', ['jshint', 'clean:distFull', 'copy:sparkIcons', 'sass:dist', 'copy:fonts', 'copy:distPost', 'copy:distImages', 'copy:js', 'concat:js', 'uglify:dist', 'copy:distPost', 'copy:renameMinJS', 'copy:renameMinCSS', 'tmpCSS', 'cmq:dist', 'postcss:dist', 'banners', 'clean:distPost']);

  // Create Partials for dev
  grunt.registerTask('examples', ['clean:tmpPartials','concat:htmlbuild','concat:htmlbuildWhiteLabel','concat:htmlbuildStickyFooter','htmlbuild']);

};
