/**
 * # Debounce
 * Debounce a function call
 *
 *
 * @module helper/debounce.js
 */

/**
 * @ignore
 */
(function (root, factory) {

  'use strict';

  if (typeof define === 'function' && define.amd) {
    define(['spark/components/base'], factory);
  }
  else if (typeof module === 'object' && module.exports) {
    module.exports = factory(require('../components/base'));
  }
  else {
    root.Spark = root.Spark || {};
    root.Spark.debounce = factory(root.Spark.BaseComponent);
  }
}(this, function (Base) {

  'use strict';

  /**
   * @param {Function} func
   * @param {Integer} delay
   */
   function debounce(func, delay) {
     var timer;
     return function() {
       var args = arguments;
       if (timer) window.clearTimeout(timer);
       timer = window.setTimeout(function() {
         func.apply(this, args);
       }, delay);
     };
   }
  Base.exportjQuery(debounce, 'debounce');

  return debounce;
}));
