/**
 * # Each
 * Apply a callback function to a list of any kind: Array, NodeList, HTMLCollection or Object.
 *
 * @example
 * each([], callback);
 * each(el.children, callback);
 * each(el.childNodes, callback);
 * each({}, callback);
 *
 * @module helper/each.js
 */

/**
 * @ignore
 */
(function(root, factory) {

  'use strict';

  if (typeof define === 'function' && define.amd) {
    define([], factory);
  } else if (typeof module === 'object' && module.exports) {
    module.exports = factory();
  } else {
    root.Spark = root.Spark || {};
    root.Spark.each = factory();
  }
}(this, function() {

  'use strict';

  /**
   * @param {Array|NodeList|HTMLCollection|Object} list
   * @param {Function} cb
   */
  function each(list, cb) {

    if (!list) {
      return;
    }

    if (typeof cb !== 'function') {
      throw new Error('Cannot invoke `each` without a callback!');
    }

    var i = 0;
    var len = list.length;

    // Object
    if (len === undefined) {
      for (i in list) {
        if (i !== 'prototype' && list.hasOwnProperty(i)) {
          cb(i, list[i]);
        }
      }
    }
    // Array-like
    else {
      for (; i < len; i++) {
        cb(list[i]);
      }
    }
  }

  return each;
}));
