/**
 * # Outer Height
 * Get the outer height of an element (including margin and border)
 *
 * @example
 * outerHeight(el, computedStyles);
 *
 * @module helper/outer-height.js
 */

/**
 * @ignore
 */
(function(root, factory) {

  'use strict';

  if (typeof define === 'function' && define.amd) {
    define(['spark/components/base'], factory);
  } else if (typeof module === 'object' && module.exports) {
    module.exports = factory(require('../components/base'));
  } else {
    root.Spark = root.Spark || {};
    root.Spark.outerHeight = factory(root.Spark.BaseComponent);
  }
}(this, function(Base) {

  'use strict';

  /**
   * @param {Element} el
   * @param {Object} styles Optional Already have computed styles? Pass them in.
   */
  function outerHeight(el, styles) {

    styles = styles || window.getComputedStyle(el);

    var props = ['marginTop', 'marginBottom', 'borderTop', 'borderBottom'];
    var height = el.clientHeight;

    props.forEach(function(prop) {
      height += parseInt(styles[prop] || 0, 10);
    });

    return height;
  }

  Base.exportjQuery(outerHeight, 'outerHeight');

  return outerHeight;
}));
