/**
 * # Set Caret
 * Set the caret position in an input.
 *
 * @example
 * setCaret(el, -1);
 * setCaret(el, 2);
 *
 * @module helper/set-caret.js
 */

/**
 * @ignore
 */
(function(root, factory) {

  'use strict';

  if (typeof define === 'function' && define.amd) {
    define([], factory);
  } else if (typeof module === 'object' && module.exports) {
    module.exports = factory();
  } else {
    root.Spark = root.Spark || {};
    root.Spark.setCaret = factory();
  }
}(this, function() {

  'use strict';

  return function setCaret(el, start, end) {

    var originalActiveElement = document.activeElement;

    start = start < 0 ? el.value.length + start + 1 : start;
    end = end < 0 ? el.value.length + end + 1 : end;

    // IE support
    if (document.selection) {
      el.focus();
      var sel = document.selection.createRange();
      sel.moveStart('character', -el.value.length);
      sel.moveStart('character', start);
      sel.moveEnd('character', end !== undefined ? end : start);
      sel.select();
    } else if (el.selectionStart || el.selectionStart === 0) {
      el.selectionStart = start;
      el.selectionEnd = end !== undefined ? end : start;
    }

    // If we didn't have focus, go back to focusing on the original
    if (originalActiveElement !== el) {
      el.blur();
      originalActiveElement.focus();
    }

    return {
      start: start,
      end: end
    };
  };
}));
