/**
 * # Transform
 * Apply a cross-browser transform style.
 *
 * @example
 * transform('translateX', '-100px');
 *
 * @module helper/transform.js
 */

/**
 * @ignore
 */
(function(root, factory) {

  'use strict';

  if (typeof define === 'function' && define.amd) {
    define(['spark/components/base'], factory);
  } else if (typeof module === 'object' && module.exports) {
    module.exports = factory(require('../components/base'));
  } else {
    root.Spark = root.Spark || {};
    root.Spark.transform = factory(root.Spark.BaseComponent);
  }
}(this, function(Base) {

  'use strict';

  /**
   * @param {String} type
   * @param {String} val
   */
  function transform(type, val) {

    var prefixes = ['-webkit-', '-moz-', '-o-', '-ms-', ''];
    var i = 0;
    var len = prefixes.length;
    var str = '';

    for (; i < len; i++) {
      if (typeof val === 'object') {
        str += prefixes[i] + 'transform: ';

        for (var j in val) {
          str += j + '(' + val[j] + '); ';
        }
      } else {
        str += prefixes[i] + 'transform: ' + type + '(' + val + '); ';
      }
    }

    return str;
  }

  Base.exportjQuery(transform, 'transform');

  return transform;
}));
