'use strict';

// @todo Remove in 2.0.0 in favor of number selector naming

var test = require('tape');
var NumberPicker = require('../../components/number-picker');

var markup = '<div class="spark-number-picker"><button class="spark-number-picker__down"></button><input type="number" value="0"><button class="spark-number-picker__up"></button></div>';

test('should create a new instance with the proper elements', function(t) {
  var el = document.createElement('div');
  el.innerHTML = markup;
  new NumberPicker(el);
  t.end();
});

test('should get the current value as a number', function(t) {

  var el = document.createElement('div');
  el.innerHTML = markup;

  var inst = new NumberPicker(el);

  t.equal(inst.value(), parseInt(inst.inputEl.value, 10), 'value call matches input value');

  t.end();
});

test('should set the current value as a number', function(t) {

  var el = document.createElement('div');
  el.innerHTML = markup;

  var inst = new NumberPicker(el);

  t.equal(inst.value(10), 10, 'value call sets the value to 10 and returns the new value');

  inst.inputEl.setAttribute('max', 15);
  t.equal(inst.value(20), 15, 'value call returns the current value even if the value set was higher than max');

  inst.inputEl.setAttribute('min', 0);
  t.equal(inst.value(-10), 0, 'value call returns the current value even if the value set was lower than min');

  t.end();
});

test('should increment the number input', function(t) {

  var el = document.createElement('div');
  el.innerHTML = markup;

  var inst = new NumberPicker(el);

  t.equal(inst.value(), 0, 'value defaults to 0');
  inst.increment();
  t.equal(inst.value(), 1, 'value is raised by 1');

  inst.inputEl.setAttribute('step', 10);

  inst.increment();
  t.equal(inst.value(), 10, 'value is raised by `step`(10)');

  t.end();
});

test('should decrement the number input', function(t) {

  var el = document.createElement('div');
  el.innerHTML = markup;

  var inst = new NumberPicker(el);

  t.equal(inst.value(), 0, 'value defaults to 0');
  inst.decrement();
  t.equal(inst.value(), -1, 'value is lowered by 1');

  inst.inputEl.setAttribute('step', 10);

  inst.decrement();
  t.equal(inst.value(), -10, 'value is lowered by `step`(10)');

  t.end();
});
