'use strict';

var test = require('tape');
var ToggleSwitch = require('../../components/toggle-switch');
var ToggleSwitchMarkup = '<label class="spark-toggle-switch"><input class="spark-toggle__input" type="checkbox"><span class="spark-toggle-switch__handle"></span><span class="spark-toggle-switch__track"></span></label>';

test('should create ToggleSwitch component', function(t) {
  var el = document.createElement('div');
  el.innerHTML = ToggleSwitchMarkup;
  new ToggleSwitch(el);

  var el2 = document.createElement('div');
  new ToggleSwitch(el2);

  t.end();
});

test('should activate component', function(t) {
  var el = document.createElement('div');
  el.innerHTML = ToggleSwitchMarkup;
  var inst = new ToggleSwitch(el);

  inst.activate();
  t.equal(inst.input.checked, true, 'inst checked property is true after activateToggle() is called');

  t.end();
});

test('should deactive component', function(t) {
  var el = document.createElement('div');
  el.innerHTML = ToggleSwitchMarkup;
  var inst = new ToggleSwitch(el);

  inst.deactivate();
  t.equal(inst.input.checked, false, 'inst checked property is false after deactivateToggle() is called');

  t.end();
});

test('should toggle component', function(t) {
  var el = document.createElement('div');
  el.innerHTML = ToggleSwitchMarkup;
  var inst = new ToggleSwitch(el);

  inst.deactivate();
  inst.toggle();
  t.equal(inst.input.checked, true, 'inst checked property is true after deactivateToggle() and then toggle() is called');

  inst.toggle();
  t.equal(inst.input.checked, false, 'inst checked property is false after toggle() is called again');

  t.end();
});
