'use strict';

var fs = require('fs');
var sass = require('node-sass');


/**
 * Take an array of import declarations and return a string.
 * @param  {Array} imports
 * @return {String}
 */
function joinImports(imports) {

  var joined = '';

  imports.forEach(function(imp) {
    joined += '@import "node_modules/sabre-spark/scss/' + imp + '";\n';
  });

  return joined;
}


/**
 * Render SCSS.
 * @param  {String} scss
 * @return {String}
 */
function render(scss) {
  return sass.renderSync({data: scss}).css;
}


/**
 * Build a custom SASS or CSS version of Sabre Spark
 * @param  {Array} components
 * @param  {String} theme      Optional
 * @param  {String} fileName   Optional
 */
module.exports = function(components, theme, fileName) {

  // Default file name and theme
  fileName = fileName || 'spark.custom.scss';
  theme = theme !== undefined ? theme : 'light';

  // Are we writing to an scss file?
  var isScss = fileName.match(/\.scss$/) ? true : false;

  // Array of imports
  var imports = [
    'config/index',
    'functions/index',
    'mixins/index',
    'common/index',
  ];

  // Theme-specific config. This has to go after the first config.
  if (theme) {
    imports.splice(1, 0, 'themes/' + theme + '/config/index');
  }

  // Add components
  components.forEach(function(component) {
    imports.push('components/' + component);
  });

  // Theme-specific styling
  if (theme) {
    imports.push('themes/' + theme + '/index');
  }

  // Write the file
  fs.writeFile(fileName, isScss ? joinImports(imports) : render(joinImports(imports)), 'utf8', function() {
    console.log('File "' + fileName + '" written successfully.');
    process.exit(0);
  });
};
